@@ -2,7 +2,7 @@ use strict 'vars', 'subs';  # Moved to stop Perl::Critic carping when Dist::Zill
                             # $VERSION information.
 
 package DBIx::Squirrel;
-$DBIx::Squirrel::VERSION = '1.0.0'; # TRIAL
+$DBIx::Squirrel::VERSION = '1.1.0'; # TRIAL
 use warnings;
 use constant E_BAD_ENT_BIND     => 'Cannot associate with an invalid object';
 use constant E_EXP_HASH_ARR_REF => 'Expected a reference to a HASH or ARRAY';
@@ -20,7 +20,7 @@ DBIx::Squirrel - A module for working with databases
 
 =head1 VERSION
 
-version 1.0.0
+version 1.1.0
 
 =head1 SYNOPSIS
 
@@ -286,7 +286,7 @@ sub import {
 
                         if (   UNIVERSAL::isa( $_[0], 'DBI::db' )
                             or UNIVERSAL::isa( $_[0], 'DBI::st' )
-                            or UNIVERSAL::isa( $_[0], $class . '::it' ) )
+                            or UNIVERSAL::isa( $_[0], 'DBIx::Squirrel::it' ) )
                         {
                             ${$symbol} = shift;
                             return ${$symbol};
@@ -304,7 +304,7 @@ sub import {
 
                     if (@_
                         and (  UNIVERSAL::isa( ${$symbol}, 'DBI::st' )
-                            or UNIVERSAL::isa( ${$symbol}, $class . '::it' ) )
+                            or UNIVERSAL::isa( ${$symbol}, 'DBIx::Squirrel::it' ) )
                       )
                     {
                         my @params = do {
@@ -370,114 +370,79 @@ __END__
 
 =head1 DESCRIPTION
 
-B<Just what the world needs — another Perl package for working with databases!>
+The C<DBIx::Squirrel> package extends the C<DBI> by offering the
+regular C<DBI> user a few useful conveniences. Enhancements are
+subtle and progressive, and they do not detract too much from
+the normal C<DBI> experience.
 
-C<DBIx::Squirrel> is a C<DBI> extension that serves as drop-in replacement for
-C<DBI>, while adding a few progressive enhancements to make some tasks much
-easier.
-
-=head1 DESIGN
-
-=head2 Compatibility
-
-DBIx-Squirrel's baseline behaviour is be like C<DBI>.
-
-A developer should be able to confidently replace C<use DBI> with
-C<use DBIx::Squirrel>, while expecting their script to behave just
-as it did before the change.
-
-DBIx-Squirrel's enhancements are designed to be low-friction, intuitive, and
-elective. Code using this package should behave like code using DBI, that is
-until deviation from standard behaviour is expected and invited.
-
-=head2 Ease of use
-
-An experienced user of DBI, or someone familiar with DBI's documentation,
-should be able to use DBIx-Squirrel without any issues.
-
-DBIx-Squirrel's enhancements are either additive or progressive. Experienced
-DBI and DBIx-Class programmers should find a cursory glance at the synopsis
-enough to get started in next to no time at all.
-
-The intention has been for DBIx-Squirrel was to occupy a sweet spot between DBI
-and DBIx-Class (though much closer to DBI).
-
-=head1 OVERVIEW
-
-=head2 Connecting to databases, and preparing statements
+=head2 Database connection
 
 =over
 
 =item *
 
-The C<connect> method continues to work as expected. It may also be invoked
-with a single argument (another database handle), if the intention is to clone
-that connection. This is particularly useful when cloning a standard DBI
-database object, since the resulting clone will be a DBI-Squirrel
-database object.
-
-=item *
-
-Both C<prepare> and C<prepare_cached> methods continue to work as expected,
-though passing a statement handle, instead of a statement in a string, results
-in that statement being cloned. Again, this is useful when the intention is to
-clone a standard DBI statement object in order to produce a DBIx-Squirrel
-statement object.
+Connecting to a database using C<DBIx::Squirrel> works the same
+way as it does when using the C<DBI> C<connect> and C<connect_cached>
+methods. The C<DBIx::Squirrel> C<connect> method, however, can also
+accept a database handle in place of a datasource name. The database
+handle can even be a reference to a C<DBI> object. The original database
+connection will be cloned as as C<DBIx::Squirrel> object.
 
 =back
 
-=head2 Parameter placeholders, bind values, and iterators
+=head2 Statement preparation
 
 =over
 
 =item *
 
-Regardless of the database driver being used, DBIx-Squirrel provides full,
-baseline support for five parameter placeholder schemes (C<?>, C<?1>,
-C<$1>, C<:1>, C<:name>), offering a small degree of code portability to
-programmers with standard SQL, SQLite, PostgreSQL and Oracle backgrounds.
+Both C<prepare> and C<prepare_cached> methods continue to work as
+as they do in the C<DBI>, though they will also accept a statement
+handles in place of a statement strings. Again, this is useful when
+the intention is to prepare a C<DBI> statement object and represent
+it as a C<DBIx::Squirrel> statement object.
 
 =item *
 
-A statement object's C<bind_param> method will continue to work as expected,
-though its behaviour has been progressively enhanced. It now accommodates
-both C<bind_param(':name', 'value')> and C<bind_param('name', 'value')>
-calling styles, as well as the C<bind_param(1, 'value')> style for
-positional placeholders.
+Statements may be prepared using any one of a number of parameter
+placeholder styles, with support provided for named and a variety
+of positional styles. Styles supported are C<:name>, C<?1>, C<$1>,
+C<:1> and C<?>. Whether you prefer to use a particular style, or
+you are converting queries to run on a different database engine,
+any of these style will work regardless of the driver in use.
+
+=back
+
+=head2 Results processing
+
+=over
 
 =item *
 
-Statement objects have a new C<bind> method aimed at greatly streamlining
-the binding of values to statement parameters.
+A C<DBIx::Squirrel> statement can produce two kinds of iterator, to
+provide for efficient processing of results. These are generated using
+statement's C<iterate> and C<results> methods in place of C<execute>.
 
 =item *
 
-A statement object's C<execute> method will accept any arguments you would
-pass to the C<bind> method. It isn't really necessary to call C<bind> because
-C<execute> will take care of that.
+Iterators offer a declarative way to process results using callbacks
+chains to transform results before they are returned to the caller.
 
 =item *
 
-DBIx-Squirrel iterators make the traversal of result sets simple and
-efficient, and these can be generated by using a statement object's
-C<iterate> method in place of C<execute>, with both methods taking
-the same arguments.
-
-=item *
-
-Some DBIx-Squirrel iterator method names (C<reset>, C<first>, C<next>,
-C<single>, C<find>, C<all>) may be familiar to other DBIx-Class
-programmers who use them for similar purposes.
+Some DBIx-Squirrel iterator methods named C<all>, C<find>, C<first>,
+C<next>, C<single> may already be familiar to C<DBIx::Class>
+users, and they do similar jobs.
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-    The DBIx::Squirrel module is Copyright (c) 2020-2014 Iain Campbell.
-    All rights reserved.
+The DBIx::Squirrel module is Copyright (c) 2020-2014 Iain Campbell.
+All rights reserved.
 
-    You may distribute under the terms of either the GNU General Public
-    License or the Artistic License, as specified in the Perl 5.10.0 README file.
+You may distribute under the terms of either the GNU General Public
+License or the Artistic License, as specified in the Perl 5.10.0 README file.
 
 =head1 SUPPORT / WARRANTY
 
